(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7451,        240]*)
(*NotebookOutlinePosition[      9672,        307]*)
(*  CellTagsIndexPosition[      9540,        300]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Errata (State: 2015)", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Section"],
  ". Description of Diffusion"
}], "Section",
  CounterAssignments->{{"Title", 1}}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 1.1.2.1. Fick's Laws",
    FontWeight->"Bold"],
  StyleBox[" (page 16)",
    FontWeight->"Plain"]
}], "Subsection"],

Cell[TextData[{
  "Last sentence reads correctly (temperature difference ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]T\)]],
  " instead of temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "):"
}], "Text"],

Cell[TextData[{
  "Equation (1.3) also occurs in connection with Fourier's theory of heat \
conduction, where in this case the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is replaced by the temperature difference ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]T\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 1.1.4.4. Solution to the Difference Equation",
    FontWeight->"Bold"],
  StyleBox[" (page 20)",
    FontWeight->"Plain"]
}], "Subsection"],

Cell[TextData[{
  "The formula reads correctly (",
  Cell[BoxData[
      \(TraditionalForm\`v\ t - x\)]],
  " instead of ",
  Cell[BoxData[
      \(TraditionalForm\`x - v\ t\)]],
  "):"
}], "Text"],

Cell[BoxData[
    RowBox[{\(\[Rho][x, t]\), "=", 
      RowBox[{
        RowBox[{
        \(1\/\(2  v\ \[CapitalDelta]t\)\), \(1\/2\^\(t\/\[CapitalDelta]t\)\), 
          
          RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                {\(t\/\[CapitalDelta]t\)},
                {\(\(x + v\ t\)\/\(2  v\ \[CapitalDelta]t\)\)}
                }], "\[NegativeThinSpace]", ")"}]}], "=", 
        \(\((\(1\/\(2  v\ \[CapitalDelta]t\)\) 
              \(1\/2\^\(t\/\[CapitalDelta]t\)\) 
              \(\((t\/\[CapitalDelta]t)\)!
                  \)\/\(\(\((\(x + v\ t\)\/\(2  v\ \[CapitalDelta]t\))\)!\) 
                  \(\((\(v\ t - x\)\/\(2  v\ \[CapitalDelta]t\))\)!\)\))\).
          \)}]}]], "NumberedEquation",
  CounterAssignments->{{"NumberedEquation", 9}},
  CellTags->"Binomialverteilung"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 1.1.5.2. Hypothesis on Variance",
    FontWeight->"Bold"],
  StyleBox[" (page 22)",
    FontWeight->"Plain"]
}], "Subsection"],

Cell[TextData[{
  "The hypothesis in the ",
  Cell[BoxData[
      \(TraditionalForm\`3\^rd\)]],
  " paragraph is erroneous. Correct is the following, always negative \
variance:"
}], "Text"],

Cell[BoxData[
    \(\[Sigma]\^2 = 
      \(1\/2\ v\^2\ \[CapitalDelta]t\ 
          \((2\ t + \[CapitalDelta]t - 
              \[ExponentialE]\^\(\(2\ t\)\/\[CapitalDelta]t\)\ 
                \[CapitalDelta]t)\) = 
        \(2\ t\ \[Lambda] + \[CapitalDelta]t\ \[Lambda] - 
            \[ExponentialE]\^\(\(2\ t\)\/\[CapitalDelta]t\)\ \[CapitalDelta]t
              \ \[Lambda] = 
          \(-\(\(2  \[Lambda]\ t\^2\)\/\[CapitalDelta]t\)\) - 
            \(4  \[Lambda]\ t\^3\)\/\(3\ \[CapitalDelta]t\^2\) - 
            \(2  \[Lambda]\ t\^4\)\/\(3  \[CapitalDelta]t\^3\) + 
            \(O[t]\^5\ .\)\)\)\)], "Equation"],

Cell["\<\
A negative variance points to diffusion into the imaginary part and questions \
the choosen model (1.12).\
\>", "Text"],

Cell["The comparison to the variance of Cattaneo's equation", "Text"],

Cell[BoxData[
    \(\[Sigma]\^2 = 
      2  \[Lambda]\ \((t - \[Tau])\) + 
        2  \[Lambda]\ \[Tau]\ Exp[\(-t\)/\[Tau]]\)], "NumberedEquation",
  CounterAssignments->{{"NumberedEquation", 7}},
  CellTags->"Varianz der Cattaneo-Gleichung"],

Cell[TextData[{
  "yields a formal identity for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t \[Rule] \(-2\) \[Tau]\)]],
  ", but ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[Lambda] = 
        \(\(\(v\^2\) \[CapitalDelta]t\)\/2 = \(v\^2\) \[Tau] > 0\)\)]],
  " being positive in both cases\[LongDash]see equation (1.7)."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Section 1.2.2.3. Classification Scheme of Diffusive Processes\
\>", "Subsection"],

Cell["\<\
The systematics, being introduced as part of this elaboration, concerns on \
diffusive processes in free space. At boundary layers to other media, also \
mathematically for all linear equations there is partial or total reflection, \
which changes the variance behaviour totally and leads to the homogeneous \
distribution of the solution with temporal constant variance.\
\>", "Text"],

Cell[TextData[{
  "Especially in case of ",
  StyleBox["thermal reflection",
    FontSlant->"Italic"],
  ", being little payed attention to, for example in spaceships the \
phenomenon occurs, that the spaceships do not cool down in the temperature of \
space, declared to be ",
  Cell[BoxData[
      \(TraditionalForm\`3  K\)]],
  ", if just the radiation balance is ruled."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Section 1.3.3. Space Fractional Diffusion Equations", "Subsection"],

Cell["\<\
Meanwhile the proof to the variance theorem for finite limits has been \
successful (see errata to appendix A). By this opens up the possibility to \
compare also all L\[EAcute]vy distributions to measured data in the sense of \
Einstein's relation. For finite limits, the power law in variance is expected \
to be replaced by a more complicated function, the asymptotics of which of \
course again can be a power law in the corresponding measurement section. \
Because of missing results, this aspect has been examined only little in the \
current elaboration.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  CounterBox["Section"],
  ". "
}], "Section",
  PageBreakAbove->True]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 742}},
ScreenStyleEnvironment->"Printout",
PrintingStyleEnvironment->"Printout",
ShowPageBreaks->True,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{1264, 735},
WindowMargins->{{-4, Automatic}, {-4, Automatic}},
PrintingCopies->1,
PrintingStartingPageNumber->177,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Errata"}], "Header"]}, {Cell[ 
        TextData[ {"Errata"}], "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
PrivateFontOptions->{"FontType"->"Outline"},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "TeX-German.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Binomialverteilung"->{
    Cell[3074, 111, 808, 17, 60, "NumberedEquation",
      CounterAssignments->{{"NumberedEquation", 9}},
      CellTags->"Binomialverteilung"]},
  "Varianz der Cattaneo-Gleichung"->{
    Cell[5108, 169, 242, 5, 33, "NumberedEquation",
      CounterAssignments->{{"NumberedEquation", 7}},
      CellTags->"Varianz der Cattaneo-Gleichung"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Binomialverteilung", 9174, 288},
  {"Varianz der Cattaneo-Gleichung", 9358, 292}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 37, 0, 109, "Title"],

Cell[CellGroupData[{
Cell[1793, 55, 124, 4, 68, "Section",
  CounterAssignments->{{"Title", 1}}],

Cell[CellGroupData[{
Cell[1942, 63, 151, 5, 64, "Subsection"],
Cell[2096, 70, 235, 8, 32, "Text"],
Cell[2334, 80, 325, 9, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2696, 94, 175, 5, 64, "Subsection"],
Cell[2874, 101, 197, 8, 32, "Text"],
Cell[3074, 111, 808, 17, 60, "NumberedEquation",
  CounterAssignments->{{"NumberedEquation", 9}},
  CellTags->"Binomialverteilung"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3919, 133, 162, 5, 64, "Subsection"],
Cell[4084, 140, 190, 6, 32, "Text"],
Cell[4277, 148, 624, 12, 52, "Equation"],
Cell[4904, 162, 129, 3, 32, "Text"],
Cell[5036, 167, 69, 0, 32, "Text"],
Cell[5108, 169, 242, 5, 33, "NumberedEquation",
  CounterAssignments->{{"NumberedEquation", 7}},
  CellTags->"Varianz der Cattaneo-Gleichung"],
Cell[5353, 176, 356, 10, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5746, 191, 91, 2, 64, "Subsection"],
Cell[5840, 195, 395, 6, 92, "Text"],
Cell[6238, 203, 386, 10, 72, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6661, 218, 73, 0, 64, "Subsection"],
Cell[6737, 220, 585, 9, 132, "Text"]
}, Open  ]]
}, Open  ]],
Cell[7349, 233, 86, 4, 68, "Section",
  PageBreakAbove->True]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

